"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const Plugin = ({ markdownAST }, pluginOptions = {}) => {
    const { acronyms } = pluginOptions;
    if (!acronyms)
        return markdownAST;
    const acronymsRegExp = new RegExp(`\\b(${Object.keys(acronyms).join('|')})\\b`, 'g');
    unist_util_visit_1.default(markdownAST, 'text', (node, index, parent) => {
        if (node.value && typeof node.value === 'string') {
            const newNodes = node.value.split(acronymsRegExp).map((value) => {
                const acronymTitle = acronyms[value];
                return acronymTitle
                    ? {
                        type: 'html',
                        value: `<abbr title="${acronymTitle}">${value}</abbr>`,
                    }
                    : {
                        type: 'text',
                        value,
                    };
            });
            parent.children.splice(index, 1, ...newNodes);
            return index + newNodes.length;
        }
        return index + 1;
    });
    return markdownAST;
};
module.exports = Plugin;
